@@ -1,8 +1,11 @@
-from .stqscraper import DATA_DIR
 from .stqscraper.fundamentals import Fundamentals
 from .stqscraper.stockquotes import StockQuotes
 from .stqscraper.scrapers import scrap_summary_table
+from .analysis import heikinashi
+from .__storage import get_storage_dir, get_storage_status
+from datetime import datetime, timedelta
 import pandas as pd
+import numpy as np
 import os
 
 
@@ -26,11 +29,6 @@ class Stock:
         self._ohlc = StockQuotes(ticker)
         self._fundamentals = Fundamentals(ticker)
 
-    # @property
-    # def name(self):
-    #     stocks = dict()
-    #     return stocks.get(self.ticker, None)
-
     @property
     def ohlc(self):
         """
@@ -111,6 +109,39 @@ class Stock:
         output = volume.mean()
         return output
 
+    def heikinashi(self):
+        # read from file
+        file_path = os.path.join(get_storage_dir(), f'{self.ticker}_heikinashi.csv')
+        use_storage = get_storage_status()
+
+        if use_storage and os.path.exists(file_path):
+            # read csv
+            output = pd.read_csv(file_path,
+                                 index_col='Date',
+                                 parse_dates=['Date'],
+                                 date_parser=lambda x: datetime.strptime(x, '%Y-%m-%d'))
+            output = output.astype(np.float64)
+
+            # check is update needed
+            last_ohlc_date = self.ohlc.index[-1]
+            last_ha_date = output.index[-1]
+
+            if last_ohlc_date > last_ha_date:
+                first_open = (output.loc[last_ha_date, 'Open']
+                              + output.loc[last_ha_date, 'Close']) / 2
+                new_ha = heikinashi(self.ohlc[last_ha_date+timedelta(days=1):],
+                                    first_open=first_open)
+                output = pd.concat([output, new_ha])
+                output.to_csv(file_path)
+        else:
+            # calculate Heikin-Ashi
+            output = heikinashi(self.ohlc)
+
+            if use_storage:
+                output.to_csv(file_path)
+
+        return output
+
 
 if __name__ == '__main__':
     pass
